@@ -63,6 +63,20 @@ fn simple_user_journey_read_only() -> Result<()> {
 
     // SORTING
     {
+        // when hitting the M key
+        app.process_events(&mut terminal, into_keys(b"m".iter()))?;
+        assert_eq!(
+            app.state.sorting,
+            SortMode::MTimeDescending,
+            "it sets the sort mode to descending by mtime"
+        );
+        // when hitting the M key again
+        app.process_events(&mut terminal, into_keys(b"m".iter()))?;
+        assert_eq!(
+            app.state.sorting,
+            SortMode::MTimeAscending,
+            "it sets the sort mode to ascending by mtime"
+        );
         // when hitting the S key
         app.process_events(&mut terminal, into_keys(b"s".iter()))?;
         assert_eq!(
